/* Generated by generator.py */

#include <Python.h>
#include <stdlib.h>
#include <libvirt/libvirt-qemu.h>
#include "typewrappers.h"
#include "libvirt-qemu.h"

PyObject *
libvirt_qemu_virDomainQemuAttach(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
    PyObject *py_retval;
    virDomainPtr c_retval;
    virConnectPtr conn;
    PyObject *pyobj_conn;
    unsigned int pid_value;
    unsigned int flags;

    if (!PyArg_ParseTuple(args, (char *)"OII:virDomainQemuAttach", &pyobj_conn, &pid_value, &flags))
        return NULL;
    conn = (virConnectPtr) PyvirConnect_Get(pyobj_conn);

    LIBVIRT_BEGIN_ALLOW_THREADS;
    c_retval = virDomainQemuAttach(conn, pid_value, flags);
    LIBVIRT_END_ALLOW_THREADS;
    py_retval = libvirt_virDomainPtrWrap((virDomainPtr) c_retval);
    return py_retval;
}

