/* Generated by generator.py */

PyObject * libvirt_virConnResetLastError(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectClose(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectCompareCPU(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectCompareHypervisorCPU(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectDomainXMLFromNative(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectDomainXMLToNative(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectFindStoragePoolSources(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetCapabilities(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetDomainCapabilities(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetHostname(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetMaxVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetStoragePoolCapabilities(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetSysinfo(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetType(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetURI(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectIsAlive(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectIsEncrypted(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectIsSecure(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedDomains(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedInterfaces(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedNetworks(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedStoragePools(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDomains(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfInterfaces(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfNWFilters(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfNetworks(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfSecrets(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfStoragePools(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectOpen(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectOpenReadOnly(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectSetKeepAlive(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainAbortJob(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainAbortJobFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainAddIOThread(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainAgentSetResponseTimeout(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainAttachDevice(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainAttachDeviceFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainBackupBegin(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainBackupGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainBlockCommit(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainBlockJobAbort(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainBlockJobSetSpeed(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainBlockPull(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainBlockRebase(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainBlockResize(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCheckpointCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCheckpointDelete(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCheckpointFree(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCheckpointGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCheckpointGetParent(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCheckpointGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCheckpointLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCoreDump(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCoreDumpWithFormat(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCreateLinux(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCreateWithFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDefineXMLFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDelIOThread(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDelThrottleGroup(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDestroyFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDetachDevice(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDetachDeviceAlias(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDetachDeviceFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainFSTrim(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainFree(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetHostname(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetID(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetMaxMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetMaxVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetMetadata(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetOSType(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetVcpusFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGraphicsReload(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainHasCurrentSnapshot(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainHasManagedSaveImage(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainInjectNMI(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainIsActive(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainIsPersistent(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainIsUpdated(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByID(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainManagedSave(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainManagedSaveDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainManagedSaveGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainManagedSaveRemove(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrate(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrate2(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrateSetCompressionCache(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrateSetMaxDowntime(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrateSetMaxSpeed(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrateStartPostCopy(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrateToURI(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrateToURI2(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainOpenChannel(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainOpenConsole(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainOpenGraphics(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainOpenGraphicsFD(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainPMSuspendForDuration(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainPMWakeup(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainReboot(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainRename(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainReset(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainRestore(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainRestoreFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainResume(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSave(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSaveFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSaveImageDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSaveImageGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainScreenshot(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSendProcessSignal(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetAutostartOnce(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetBlockThreshold(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetGuestVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetLifecycleAction(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMaxMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMemoryFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMemoryStatsPeriod(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMetadata(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetUserPassword(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetVcpu(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetVcpusFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainShutdown(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainShutdownFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotCurrent(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotDelete(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotFree(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotGetParent(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotHasMetadata(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotIsCurrent(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotNum(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSnapshotNumChildren(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainStartDirtyRateCalc(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSuspend(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainUndefineFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainUpdateDeviceFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virEventRegisterDefaultImpl(PyObject *self, PyObject *args);
PyObject * libvirt_virEventRemoveHandle(PyObject *self, PyObject *args);
PyObject * libvirt_virEventRemoveTimeout(PyObject *self, PyObject *args);
PyObject * libvirt_virEventRunDefaultImpl(PyObject *self, PyObject *args);
PyObject * libvirt_virEventUpdateHandle(PyObject *self, PyObject *args);
PyObject * libvirt_virEventUpdateTimeout(PyObject *self, PyObject *args);
PyObject * libvirt_virGetLastErrorCode(PyObject *self, PyObject *args);
PyObject * libvirt_virGetLastErrorDomain(PyObject *self, PyObject *args);
PyObject * libvirt_virGetLastErrorMessage(PyObject *self, PyObject *args);
PyObject * libvirt_virInitialize(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceChangeBegin(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceChangeCommit(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceChangeRollback(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceFree(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceGetMACString(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceIsActive(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceLookupByMACString(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virInterfaceUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterBindingCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterBindingDelete(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterBindingFree(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterBindingGetFilterName(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterBindingGetPortDev(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterBindingGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterBindingLookupByPortDev(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterDefineXMLFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterFree(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virNWFilterUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkCreateXMLFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkDefineXMLFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkFree(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetBridgeName(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetMetadata(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkIsActive(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkIsPersistent(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkPortCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkPortDelete(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkPortFree(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkPortGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkPortLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkSetMetadata(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkUpdate(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceDetachFlags(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceDettach(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceFree(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceGetParent(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceIsActive(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceIsPersistent(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceLookupSCSIHostByWWN(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceNumOfCaps(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceReAttach(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceReset(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeDeviceUpdate(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeGetFreeMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeNumOfDevices(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeSuspendForDuration(PyObject *self, PyObject *args);
PyObject * libvirt_virResetLastError(PyObject *self, PyObject *args);
PyObject * libvirt_virSecretDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virSecretFree(PyObject *self, PyObject *args);
PyObject * libvirt_virSecretGetUsageID(PyObject *self, PyObject *args);
PyObject * libvirt_virSecretGetUsageType(PyObject *self, PyObject *args);
PyObject * libvirt_virSecretGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virSecretLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virSecretLookupByUsage(PyObject *self, PyObject *args);
PyObject * libvirt_virSecretUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolBuild(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolDelete(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolFree(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolIsActive(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolIsPersistent(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolLookupByTargetPath(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolLookupByVolume(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolNumOfVolumes(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolRefresh(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolCreateXMLFrom(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolDelete(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolDownload(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolFree(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetKey(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetPath(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolLookupByKey(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolLookupByPath(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolResize(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolUpload(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolWipe(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolWipePattern(PyObject *self, PyObject *args);
PyObject * libvirt_virStreamAbort(PyObject *self, PyObject *args);
PyObject * libvirt_virStreamEventRemoveCallback(PyObject *self, PyObject *args);
PyObject * libvirt_virStreamEventUpdateCallback(PyObject *self, PyObject *args);
PyObject * libvirt_virStreamFinish(PyObject *self, PyObject *args);
PyObject * libvirt_virStreamFree(PyObject *self, PyObject *args);
PyObject * libvirt_virStreamNew(PyObject *self, PyObject *args);
PyObject *libvirt_virDomain_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virNetwork_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virNetworkPort_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virInterface_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virStoragePool_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virStorageVol_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virConnect_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virNodeDevice_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virSecret_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virNWFilter_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virNWFilterBinding_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virStream_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virDomainCheckpoint_pointer(PyObject *self, PyObject *args);
PyObject *libvirt_virDomainSnapshot_pointer(PyObject *self, PyObject *args);
#define VIR_DOMAIN_EVENT_ID_AGENT_LIFECYCLE VIR_DOMAIN_EVENT_ID_AGENT_LIFECYCLE
#define VIR_DOMAIN_EVENT_ID_BALLOON_CHANGE VIR_DOMAIN_EVENT_ID_BALLOON_CHANGE
#define VIR_DOMAIN_EVENT_ID_BLOCK_JOB VIR_DOMAIN_EVENT_ID_BLOCK_JOB
#define VIR_DOMAIN_EVENT_ID_BLOCK_JOB_2 VIR_DOMAIN_EVENT_ID_BLOCK_JOB_2
#define VIR_DOMAIN_EVENT_ID_BLOCK_THRESHOLD VIR_DOMAIN_EVENT_ID_BLOCK_THRESHOLD
#define VIR_DOMAIN_EVENT_ID_CONTROL_ERROR VIR_DOMAIN_EVENT_ID_CONTROL_ERROR
#define VIR_DOMAIN_EVENT_ID_DEVICE_ADDED VIR_DOMAIN_EVENT_ID_DEVICE_ADDED
#define VIR_DOMAIN_EVENT_ID_DEVICE_REMOVAL_FAILED VIR_DOMAIN_EVENT_ID_DEVICE_REMOVAL_FAILED
#define VIR_DOMAIN_EVENT_ID_DEVICE_REMOVED VIR_DOMAIN_EVENT_ID_DEVICE_REMOVED
#define VIR_DOMAIN_EVENT_ID_DISK_CHANGE VIR_DOMAIN_EVENT_ID_DISK_CHANGE
#define VIR_DOMAIN_EVENT_ID_GRAPHICS VIR_DOMAIN_EVENT_ID_GRAPHICS
#define VIR_DOMAIN_EVENT_ID_IO_ERROR VIR_DOMAIN_EVENT_ID_IO_ERROR
#define VIR_DOMAIN_EVENT_ID_IO_ERROR_REASON VIR_DOMAIN_EVENT_ID_IO_ERROR_REASON
#define VIR_DOMAIN_EVENT_ID_JOB_COMPLETED VIR_DOMAIN_EVENT_ID_JOB_COMPLETED
#define VIR_DOMAIN_EVENT_ID_LAST VIR_DOMAIN_EVENT_ID_LAST
#define VIR_DOMAIN_EVENT_ID_LIFECYCLE VIR_DOMAIN_EVENT_ID_LIFECYCLE
#define VIR_DOMAIN_EVENT_ID_MEMORY_DEVICE_SIZE_CHANGE VIR_DOMAIN_EVENT_ID_MEMORY_DEVICE_SIZE_CHANGE
#define VIR_DOMAIN_EVENT_ID_MEMORY_FAILURE VIR_DOMAIN_EVENT_ID_MEMORY_FAILURE
#define VIR_DOMAIN_EVENT_ID_METADATA_CHANGE VIR_DOMAIN_EVENT_ID_METADATA_CHANGE
#define VIR_DOMAIN_EVENT_ID_MIGRATION_ITERATION VIR_DOMAIN_EVENT_ID_MIGRATION_ITERATION
#define VIR_DOMAIN_EVENT_ID_NIC_MAC_CHANGE VIR_DOMAIN_EVENT_ID_NIC_MAC_CHANGE
#define VIR_DOMAIN_EVENT_ID_PMSUSPEND VIR_DOMAIN_EVENT_ID_PMSUSPEND
#define VIR_DOMAIN_EVENT_ID_PMSUSPEND_DISK VIR_DOMAIN_EVENT_ID_PMSUSPEND_DISK
#define VIR_DOMAIN_EVENT_ID_PMWAKEUP VIR_DOMAIN_EVENT_ID_PMWAKEUP
#define VIR_DOMAIN_EVENT_ID_REBOOT VIR_DOMAIN_EVENT_ID_REBOOT
#define VIR_DOMAIN_EVENT_ID_RTC_CHANGE VIR_DOMAIN_EVENT_ID_RTC_CHANGE
#define VIR_DOMAIN_EVENT_ID_TRAY_CHANGE VIR_DOMAIN_EVENT_ID_TRAY_CHANGE
#define VIR_DOMAIN_EVENT_ID_TUNABLE VIR_DOMAIN_EVENT_ID_TUNABLE
#define VIR_DOMAIN_EVENT_ID_WATCHDOG VIR_DOMAIN_EVENT_ID_WATCHDOG
#define VIR_NETWORK_EVENT_ID_LAST VIR_NETWORK_EVENT_ID_LAST
#define VIR_NETWORK_EVENT_ID_LIFECYCLE VIR_NETWORK_EVENT_ID_LIFECYCLE
#define VIR_NETWORK_EVENT_ID_METADATA_CHANGE VIR_NETWORK_EVENT_ID_METADATA_CHANGE
